@@ -163,6 +163,9 @@ void MpvItem::setupConnections()
     connect(m_mpvController, &MpvController::endFile,
             this, &MpvItem::endFile, Qt::QueuedConnection);
 
+    connect(m_mpvController, &MpvController::videoReconfig,
+            this, &MpvItem::videoReconfig, Qt::QueuedConnection);
+
     connect(this, &MpvItem::fileLoaded, this, [=]() {
         if (!getProperty(QStringLiteral("vid")).toBool()) {
             command(QStringList{QStringLiteral("video-add"), VideoSettings::defaultCover()});
@@ -481,21 +484,6 @@ void MpvItem::onPropertyChanged(const QString &property, const QVariant &value)
     }
 }
 
-void MpvItem::cachePropertyValue(const QString &property, const QVariant &value)
-{
-    m_propertiesCache[property] = value;
-}
-
-QVariant MpvItem::getCachedPropertyValue(const QString &property)
-{
-    if (!m_propertiesCache[property].isValid()) {
-        auto value = getProperty(property);
-        cachePropertyValue(property, value);
-        return value;
-    }
-    return m_propertiesCache[property];
-}
-
 double MpvItem::watchPercentage()
 {
     return m_watchPercentage;
@@ -512,9 +500,10 @@ void MpvItem::setWatchPercentage(double value)
 
 void MpvItem::loadFile(const QString &file)
 {
-    command(QStringList() << QStringLiteral("loadfile") << file);
+    m_currentFile = file;
+    command(QStringList() << QStringLiteral("loadfile") << m_currentFile);
 
-    GeneralSettings::setLastPlayedFile(file);
+    GeneralSettings::setLastPlayedFile(m_currentFile);
     GeneralSettings::self()->save();
 }
 
@@ -665,4 +654,9 @@ QString MpvItem::formattedPosition() const
     return m_formattedPosition;
 }
 
+QString MpvItem::currentFile() const
+{
+    return m_currentFile;
+}
+
 #include "moc_mpvitem.cpp"
