@@ -25,6 +25,7 @@ class MpvItem : public MpvAbstractItem
     // this property is used to pause the player
     Q_PROPERTY(bool isFileReloaded READ isFileReloaded WRITE setIsFileReloaded NOTIFY isFileReloadedChanged)
     Q_PROPERTY(QString mediaTitle READ mediaTitle NOTIFY mediaTitleChanged)
+    Q_PROPERTY(QString currentFile READ currentFile NOTIFY mediaTitleChanged)
     Q_PROPERTY(double position READ position WRITE setPosition NOTIFY positionChanged)
     // cache the watch later time position to be used by the seekToWatchLaterPosition action
     // useful when resuming playback is disabled
@@ -88,7 +89,6 @@ class MpvItem : public MpvAbstractItem
     void setSecondarySubtitleId(int value);
 
     void onPropertyChanged(const QString &property, const QVariant &value);
-    void cachePropertyValue(const QString &property, const QVariant &value);
 
 public:
     explicit MpvItem(QQuickItem *parent = nullptr);
@@ -103,7 +103,8 @@ public:
     Q_INVOKABLE QString formattedPosition() const;
     Q_INVOKABLE QString formattedRemaining() const;
     Q_INVOKABLE QString formattedDuration() const;
-    Q_INVOKABLE QVariant getCachedPropertyValue(const QString &property);
+
+    QString currentFile() const;
 
 Q_SIGNALS:
     void audioTracksModelChanged();
@@ -129,6 +130,7 @@ Q_SIGNALS:
     void fileStarted();
     void fileLoaded();
     void endFile(QString reason);
+    void videoReconfig();
     void syncConfigValue(QString path, QString group, QString key, QVariant value);
 
     // signals used for mpris
@@ -152,7 +154,6 @@ private:
     double m_watchPercentage{0.0};
     PlayListModel *m_playlistModel;
     PlayListProxyModel *m_playlistProxyModel;
-    QString m_file;
 
     double m_position{0.0};
     QString m_formattedPosition;
@@ -161,9 +162,9 @@ private:
     double m_duration{0.0};
     QString m_formattedDuration;
 
-    QMap<QString, QVariant> m_propertiesCache;
     double m_watchLaterPosition{0.0};
     bool m_isFileReloaded{false};
+    QString m_currentFile;
 };
 
 #endif // MPVOBJECT_H
